pub fn create_render_effect<T>(
fun: impl FnMut(Option<T>) -> T + 'static,
) -> RenderEffect<T>where
T: 'static,👎Deprecated:
This function is being removed to conform to Rust idioms. Please use RenderEffect::new() instead.
Creates a new render effect, which immediately runs fun.