pub struct SignalSetter<T, S = SyncStorage>where
T: 'static,{ /* private fields */ }Expand description
A wrapper for any kind of settable reactive signal: a WriteSignal,
RwSignal, or closure that receives a value and sets a signal depending
on it.
This allows you to create APIs that take any kind of SignalSetter<T> as an argument,
rather than adding a generic F: Fn(T). Values can be set with the same
function call or set(), API as other signals.
Core Trait Implementations
.set()(or calling the setter as a function) sets the signal’s value, and notifies all subscribers that the signal’s value has changed. to subscribe to the signal, and to re-run whenever the value of the signal changes.
Examples
let (count, set_count) = signal(2);
let set_double_input = SignalSetter::map(move |n| set_count.set(n * 2));
// this function takes any kind of signal setter
fn set_to_4(setter: &SignalSetter<i32>) {
// ✅ calling the signal sets the value
// can be `setter(4)` on nightly
setter.set(4);
}
set_to_4(&set_count.into());
assert_eq!(count.get(), 4);
set_to_4(&set_double_input);
assert_eq!(count.get(), 8);Implementations