pub struct UnsyncCallback<In, Out = ()>(/* private fields */)
where
In: 'static,
Out: 'static;Expand description
A callback type that is not required to be Send or Sync.
Example
let _: UnsyncCallback<()> = UnsyncCallback::new(|_| {});
let _: UnsyncCallback<(i32, i32)> = (|_x: i32, _y: i32| {}).into();
let cb: UnsyncCallback<i32, String> = UnsyncCallback::new(|x: i32| x.to_string());
assert_eq!(cb.run(42), "42".to_string());Implementations
Sourceimpl<In, Out> UnsyncCallback<In, Out>
impl<In, Out> UnsyncCallback<In, Out>
Sourcepub fn new<F>(f: F) -> UnsyncCallback<In, Out>where
F: Fn(In) -> Out + 'static,
pub fn new<F>(f: F) -> UnsyncCallback<In, Out>where
F: Fn(In) -> Out + 'static,
Creates a new callback from the given function.
Sourcepub fn matches(&self, other: &UnsyncCallback<In, Out>) -> bool
pub fn matches(&self, other: &UnsyncCallback<In, Out>) -> bool
Returns true if both callbacks wrap the same underlying function pointer.